@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -30,8 +30,7 @@ MAILMAN_DAY = 1
 
 
 def postorius(request):
-    """Add template variables to context.
-    """
+    """Add template variables to context."""
     return dict(
         POSTORIUS_VERSION=__version__,
         # Mailman Day is first of every month.
